# coding: utf-8

"""
    Fincura API

    This [REST API](https://en.wikipedia.org/wiki/Representational_state_transfer) allows you to interact with the Fincura processing and insights engine.   # Authentication  This API uses API keys generated from a Fincura User account. To get access to your User account, speak with you Fincura account manager.  # Accepted Media Types  | File&nbsp;Type&nbsp;&nbsp;&nbsp;&nbsp;&nbsp; | Extension(s)     | Content-Type(s) | | -------------------------------- |-------------- | ------------ | | PDF File | .pdf | `application/pdf` , `application/x-pdf` | | Excel File | .xls | `application/vnd.ms-excel`  | | Excel File | .xlsx | `application/vnd.openxmlformats-officedocument.spreadsheetml.sheet`  | | Excel File | .xlsm | `application/vnd.ms-excel.sheet.macroEnabled.12`  | | PNG Image | .png | `image/png`  | | GIF Image | .gif | `image/gif`  | | JPG Image | .jpg, .jpeg | `image/jpeg`  | | GIF Image | .gif | `image/gif`  |   # Getting Started  1. [Create a Borrower](#operation/createBorrower)  2. [Add a file](#operation/createDocumentFile) for that Borrower. 3. Analyze in the Fincura App  ****  # noqa: E501

    The version of the OpenAPI document: 1.2.6
    Contact: support@fincura.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from fincura.api_client import ApiClient, Endpoint
from fincura.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from fincura.model.data_view import DataView


class DataViewsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        def __retrieve_data_view_from_document_file(
            self,
            document_file_uuid,
            **kwargs
        ):
            """Get DataView from a DocumentFile  # noqa: E501

            Retrieve a DataView from the standardized output of a DocumentFile submitted to Fincura  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.retrieve_data_view_from_document_file(document_file_uuid, async_req=True)
            >>> result = thread.get()

            Args:
                document_file_uuid (str):

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                DataView
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['document_file_uuid'] = \
                document_file_uuid
            return self.call_with_http_info(**kwargs)

        self.retrieve_data_view_from_document_file = Endpoint(
            settings={
                'response_type': (DataView,),
                'auth': [
                    'API_Key'
                ],
                'endpoint_path': '/v1/data-view/from_document_file/{document_file_uuid}',
                'operation_id': 'retrieve_data_view_from_document_file',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'document_file_uuid',
                ],
                'required': [
                    'document_file_uuid',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'document_file_uuid':
                        (str,),
                },
                'attribute_map': {
                    'document_file_uuid': 'document_file_uuid',
                },
                'location_map': {
                    'document_file_uuid': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__retrieve_data_view_from_document_file
        )

        def __retrieve_most_recent_data_view(
            self,
            borrower_uuid,
            **kwargs
        ):
            """Get the most recent period of data for a Borrower  # noqa: E501

            Retrieve a DataView from the most recent standardized data for a borrower  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.retrieve_most_recent_data_view(borrower_uuid, async_req=True)
            >>> result = thread.get()

            Args:
                borrower_uuid (str):

            Keyword Args:
                reporting_interval (str): Reporting Interval of the financial data. [optional]
                preparation_type (str): Preparation Type of the finanical data. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                DataView
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['borrower_uuid'] = \
                borrower_uuid
            return self.call_with_http_info(**kwargs)

        self.retrieve_most_recent_data_view = Endpoint(
            settings={
                'response_type': (DataView,),
                'auth': [
                    'API_Key'
                ],
                'endpoint_path': '/v1/data-view/most_recent/{borrower_uuid}',
                'operation_id': 'retrieve_most_recent_data_view',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'borrower_uuid',
                    'reporting_interval',
                    'preparation_type',
                ],
                'required': [
                    'borrower_uuid',
                ],
                'nullable': [
                ],
                'enum': [
                    'reporting_interval',
                    'preparation_type',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('reporting_interval',): {

                        "MONTHLY": "MONTHLY",
                        "QUARTERLY": "QUARTERLY",
                        "SEMI_ANNUALLY": "SEMI_ANNUALLY",
                        "ANNUALLY": "ANNUALLY",
                        "FISCAL_YTD": "FISCAL_YTD"
                    },
                    ('preparation_type',): {

                        "UNQUALIFIED": "UNQUALIFIED",
                        "QUALIFIED": "QUALIFIED",
                        "TAX_RETURN": "TAX_RETURN",
                        "REVIEWED": "REVIEWED",
                        "CPA_PREP": "CPA_PREP",
                        "NTR": "NTR",
                        "MANAGEMENT": "MANAGEMENT",
                        "UNKNOWN": "UNKNOWN",
                        "CALCULATED": "CALCULATED"
                    },
                },
                'openapi_types': {
                    'borrower_uuid':
                        (str,),
                    'reporting_interval':
                        (str,),
                    'preparation_type':
                        (str,),
                },
                'attribute_map': {
                    'borrower_uuid': 'borrower_uuid',
                    'reporting_interval': 'reporting_interval',
                    'preparation_type': 'preparation_type',
                },
                'location_map': {
                    'borrower_uuid': 'path',
                    'reporting_interval': 'query',
                    'preparation_type': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__retrieve_most_recent_data_view
        )



# coding: utf-8

# flake8: noqa

# Import all APIs into this package.
# If you have many APIs here with many many models used in each API this may
# raise a `RecursionError`.
# In order to avoid this, import only the API that you directly need like:
#
#   from .api.api_key_api import ApiKeyApi
#
# or import this package, but before doing it, use:
#
#   import sys
#   sys.setrecursionlimit(n)

# Import APIs into API package:
from fincura.api.api_key_api import ApiKeyApi
from fincura.api.borrowers_api import BorrowersApi
from fincura.api.custom_attributes_api import CustomAttributesApi
from fincura.api.data_views_api import DataViewsApi
from fincura.api.embedded_workflows_api import EmbeddedWorkflowsApi
from fincura.api.files_api import FilesApi
from fincura.api.loans_api import LoansApi
from fincura.api.portfolios_api import PortfoliosApi
from fincura.api.requirements_api import RequirementsApi
from fincura.api.tenant_settings_api import TenantSettingsApi
from fincura.api.webhooks_api import WebhooksApi



# coding: utf-8

"""
    Fincura API

    This [REST API](https://en.wikipedia.org/wiki/Representational_state_transfer) allows you to interact with the Fincura processing and insights engine.   # Authentication  This API uses API keys generated from a Fincura User account. To get access to your User account, speak with you Fincura account manager.  # Accepted Media Types  | File&nbsp;Type&nbsp;&nbsp;&nbsp;&nbsp;&nbsp; | Extension(s)     | Content-Type(s) | | -------------------------------- |-------------- | ------------ | | PDF File | .pdf | `application/pdf` , `application/x-pdf` | | Excel File | .xls | `application/vnd.ms-excel`  | | Excel File | .xlsx | `application/vnd.openxmlformats-officedocument.spreadsheetml.sheet`  | | Excel File | .xlsm | `application/vnd.ms-excel.sheet.macroEnabled.12`  | | PNG Image | .png | `image/png`  | | GIF Image | .gif | `image/gif`  | | JPG Image | .jpg, .jpeg | `image/jpeg`  | | GIF Image | .gif | `image/gif`  |   # Getting Started  1. [Create a Borrower](#operation/createBorrower)  2. [Add a file](#operation/createDocumentFile) for that Borrower. 3. Analyze in the Fincura App  ****  # noqa: E501

    The version of the OpenAPI document: 1.2.6
    Contact: support@fincura.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import fincura
from fincura.model.custom_attribute_definition import CustomAttributeDefinition


class TestCustomAttributeDefinition(unittest.TestCase):
    """CustomAttributeDefinition unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCustomAttributeDefinition(self):
        """Test CustomAttributeDefinition"""
        # FIXME: construct object with mandatory attributes with example values
        # model = CustomAttributeDefinition()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import os
import sys
import logging
from functools import wraps

from fincura import Configuration
from fincura.api_client import ApiClient
from fincura.model.api_key import ApiKey
from fincura.apis import  (
    ApiKeyApi,
    BorrowersApi,
    CustomAttributesApi,
    DataViewsApi,
    EmbeddedWorkflowsApi,
    FilesApi,
    LoansApi,
    PortfoliosApi,
    RequirementsApi,
    TenantSettingsApi,
    WebhooksApi,
)
from fincura import (
	Configuration,
    ApiKeyApi,
    BorrowersApi,
    CustomAttributesApi,
    DataViewsApi,
    EmbeddedWorkflowsApi,
    FilesApi,
    LoansApi,
    PortfoliosApi,
    RequirementsApi,
    TenantSettingsApi,
    WebhooksApi,
)
from fincura.rest import ApiException

TENANT_ID =  os.environ.get('FINCURA_TENANT_ID')
REFRESH_TOKEN = str(os.environ['FINCURA_API_REFRESH_TOKEN'])

FINCURA_ENV = os.environ['FINCURA_ENV']

if FINCURA_ENV == 'local':
	host = "https://api-local.fincura.com:8000"
elif FINCURA_ENV == 'production':
	host = "https://api.fincura.com"
else:
	host = "https://api-%s.fincura.com" % FINCURA_ENV

# Configure API key authorization: ApiKeyAuth
configuration = Configuration(host=host)
configuration.verify_ssl = FINCURA_ENV != 'local' # for debug only
configuration.client_side_validation = False
configuration.api_key['API_Key'] = None
configuration.api_key_prefix['API_Key'] = 'Bearer'

# create an instance of the API class
api_key_api = ApiKeyApi(ApiClient(configuration))
borrowers_api = BorrowersApi(ApiClient(configuration))
custom_attributes_api = CustomAttributesApi(ApiClient(configuration))
data_views_api = DataViewsApi(ApiClient(configuration))
embedded_workflows_api = EmbeddedWorkflowsApi(ApiClient(configuration))
files_api = FilesApi(ApiClient(configuration))
loans_api = LoansApi(ApiClient(configuration))
portfolios_api = PortfoliosApi(ApiClient(configuration))
requirements_api = RequirementsApi(ApiClient(configuration))
tenant_settings_api = TenantSettingsApi(ApiClient(configuration))
webhooks_api = WebhooksApi(ApiClient(configuration))

APIS = [
    "api_key_api",
    "borrowers_api",
    "custom_attributes_api",
    "data_views_api",
    "embedded_workflows_api",
    "files_api",
    "loans_api",
    "portfolios_api",
    "requirements_api",
    "tenant_settings_api",
    "webhooks_api",
]

class Clients(object):
    pass

clients = Clients()

for api_name in APIS:
    client_name = f"{api_name.rpartition('_api')[0]}_client"
    setattr(clients, client_name, locals()[api_name])


def ensure_api_access(function):
	@wraps(function)
	def wrap(request, *args, **kwargs):
		# TODO - check current access, dont refresh if still valid
	    refresh_access_token()
	    return function(request, *args, **kwargs)
	return wrap

def refresh_access_token():
	refresh_response = clients.api_key_client.refresh_api_key(
		api_key=ApiKey(refresh_token=REFRESH_TOKEN, tenant_id=TENANT_ID)
	)
	configuration.access_token = refresh_response.access_token


# coding: utf-8

"""
    Fincura API

    This [REST API](https://en.wikipedia.org/wiki/Representational_state_transfer) allows you to interact with the Fincura processing and insights engine.   # Authentication  This API uses API keys generated from a Fincura User account. To get access to your User account, speak with you Fincura account manager.  # Accepted Media Types  | File&nbsp;Type&nbsp;&nbsp;&nbsp;&nbsp;&nbsp; | Extension(s)     | Content-Type(s) | | -------------------------------- |-------------- | ------------ | | PDF File | .pdf | `application/pdf` , `application/x-pdf` | | Excel File | .xls | `application/vnd.ms-excel`  | | Excel File | .xlsx | `application/vnd.openxmlformats-officedocument.spreadsheetml.sheet`  | | Excel File | .xlsm | `application/vnd.ms-excel.sheet.macroEnabled.12`  | | PNG Image | .png | `image/png`  | | GIF Image | .gif | `image/gif`  | | JPG Image | .jpg, .jpeg | `image/jpeg`  | | GIF Image | .gif | `image/gif`  |   # Getting Started  1. [Create a Borrower](#operation/createBorrower)  2. [Add a file](#operation/createDocumentFile) for that Borrower. 3. Analyze in the Fincura App  ****  # noqa: E501

    The version of the OpenAPI document: 1.2.6
    Contact: support@fincura.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from fincura.api_client import ApiClient, Endpoint
from fincura.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from fincura.model.inline_response2002 import InlineResponse2002
from fincura.model.portfolio import Portfolio


class PortfoliosApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        def __create_portfolio(
            self,
            **kwargs
        ):
            """Create a new Portfolio  # noqa: E501

            Create a new Portfolio record  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.create_portfolio(async_req=True)
            >>> result = thread.get()


            Keyword Args:
                portfolio (Portfolio): [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                Portfolio
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            return self.call_with_http_info(**kwargs)

        self.create_portfolio = Endpoint(
            settings={
                'response_type': (Portfolio,),
                'auth': [
                    'API_Key'
                ],
                'endpoint_path': '/v1/portfolio',
                'operation_id': 'create_portfolio',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'portfolio',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'portfolio':
                        (Portfolio,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'portfolio': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json',
                    'application/x-www-form-urlencoded',
                    'multipart/form-data'
                ]
            },
            api_client=api_client,
            callable=__create_portfolio
        )

        def __list_portfolios(
            self,
            **kwargs
        ):
            """List Portfolios  # noqa: E501

            List Portfolio records  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.list_portfolios(async_req=True)
            >>> result = thread.get()


            Keyword Args:
                limit (int): Number of results to return per page.. [optional]
                offset (int): The initial index from which to return the results.. [optional]
                search (str): A search term.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                InlineResponse2002
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            return self.call_with_http_info(**kwargs)

        self.list_portfolios = Endpoint(
            settings={
                'response_type': (InlineResponse2002,),
                'auth': [
                    'API_Key'
                ],
                'endpoint_path': '/v1/portfolio',
                'operation_id': 'list_portfolios',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'limit',
                    'offset',
                    'search',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'limit':
                        (int,),
                    'offset':
                        (int,),
                    'search':
                        (str,),
                },
                'attribute_map': {
                    'limit': 'limit',
                    'offset': 'offset',
                    'search': 'search',
                },
                'location_map': {
                    'limit': 'query',
                    'offset': 'query',
                    'search': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__list_portfolios
        )

        def __partial_update_portfolio(
            self,
            uuid,
            **kwargs
        ):
            """Update a Portfolio  # noqa: E501

            Update a Portfolio  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.partial_update_portfolio(uuid, async_req=True)
            >>> result = thread.get()

            Args:
                uuid (str):

            Keyword Args:
                search (str): A search term.. [optional]
                portfolio (Portfolio): [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                Portfolio
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['uuid'] = \
                uuid
            return self.call_with_http_info(**kwargs)

        self.partial_update_portfolio = Endpoint(
            settings={
                'response_type': (Portfolio,),
                'auth': [
                    'API_Key'
                ],
                'endpoint_path': '/v1/portfolio/{uuid}',
                'operation_id': 'partial_update_portfolio',
                'http_method': 'PATCH',
                'servers': None,
            },
            params_map={
                'all': [
                    'uuid',
                    'search',
                    'portfolio',
                ],
                'required': [
                    'uuid',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'uuid':
                        (str,),
                    'search':
                        (str,),
                    'portfolio':
                        (Portfolio,),
                },
                'attribute_map': {
                    'uuid': 'uuid',
                    'search': 'search',
                },
                'location_map': {
                    'uuid': 'path',
                    'search': 'query',
                    'portfolio': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json',
                    'application/x-www-form-urlencoded',
                    'multipart/form-data'
                ]
            },
            api_client=api_client,
            callable=__partial_update_portfolio
        )



# coding: utf-8

"""
    Fincura API

    This [REST API](https://en.wikipedia.org/wiki/Representational_state_transfer) allows you to interact with the Fincura processing and insights engine.   # Authentication  This API uses API keys generated from a Fincura User account. To get access to your User account, speak with you Fincura account manager.  # Accepted Media Types  | File&nbsp;Type&nbsp;&nbsp;&nbsp;&nbsp;&nbsp; | Extension(s)     | Content-Type(s) | | -------------------------------- |-------------- | ------------ | | PDF File | .pdf | `application/pdf` , `application/x-pdf` | | Excel File | .xls | `application/vnd.ms-excel`  | | Excel File | .xlsx | `application/vnd.openxmlformats-officedocument.spreadsheetml.sheet`  | | Excel File | .xlsm | `application/vnd.ms-excel.sheet.macroEnabled.12`  | | PNG Image | .png | `image/png`  | | GIF Image | .gif | `image/gif`  | | JPG Image | .jpg, .jpeg | `image/jpeg`  | | GIF Image | .gif | `image/gif`  |   # Getting Started  1. [Create a Borrower](#operation/createBorrower)  2. [Add a file](#operation/createDocumentFile) for that Borrower. 3. Analyze in the Fincura App  ****  # noqa: E501

    The version of the OpenAPI document: 1.2.6
    Contact: support@fincura.com
    Generated by: https://openapi-generator.tech
"""


from setuptools import setup, find_packages  # noqa: H301

NAME = "fincura-api-client"
VERSION = "1.0.1"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = [
  "urllib3 >= 1.15",
  "certifi",
  "python-dateutil",
  "nulltype",
]

setup(
    name=NAME,
    version=VERSION,
    description="Fincura API",
    author="Fincura Engineering",
    author_email="support@fincura.com",
    url="http://yada",
    keywords=["OpenAPI", "OpenAPI-Generator", "Fincura API"],
    python_requires=">=3.5",
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    long_description="""This python client allows you to interact with the Fincura processing and insights engine."""
)



# coding: utf-8

# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from fincura.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from fincura.model.api_key import ApiKey
from fincura.model.borrower import Borrower
from fincura.model.bulk_file_create import BulkFileCreate
from fincura.model.bulk_file_read import BulkFileRead
from fincura.model.custom_attribute_definition import CustomAttributeDefinition
from fincura.model.data_view import DataView
from fincura.model.data_view_calculated_value import DataViewCalculatedValue
from fincura.model.data_view_calculated_value_line_item import DataViewCalculatedValueLineItem
from fincura.model.data_view_cell_format import DataViewCellFormat
from fincura.model.data_view_cells import DataViewCells
from fincura.model.data_view_columns import DataViewColumns
from fincura.model.data_view_row_format import DataViewRowFormat
from fincura.model.data_view_rows import DataViewRows
from fincura.model.document_file_create import DocumentFileCreate
from fincura.model.document_file_create_statements import DocumentFileCreateStatements
from fincura.model.document_file_read import DocumentFileRead
from fincura.model.embedded_workflow import EmbeddedWorkflow
from fincura.model.embedded_workflow_ui_controls import EmbeddedWorkflowUiControls
from fincura.model.financial_requirement import FinancialRequirement
from fincura.model.financial_requirement_rules import FinancialRequirementRules
from fincura.model.inline_response200 import InlineResponse200
from fincura.model.inline_response2001 import InlineResponse2001
from fincura.model.inline_response2002 import InlineResponse2002
from fincura.model.inline_response2003 import InlineResponse2003
from fincura.model.inline_response2004 import InlineResponse2004
from fincura.model.inline_response2005 import InlineResponse2005
from fincura.model.inline_response2006 import InlineResponse2006
from fincura.model.loan import Loan
from fincura.model.loan_borrower_info import LoanBorrowerInfo
from fincura.model.loan_compliance_info import LoanComplianceInfo
from fincura.model.loan_documents import LoanDocuments
from fincura.model.loan_financials import LoanFinancials
from fincura.model.loan_financials_calculated_value import LoanFinancialsCalculatedValue
from fincura.model.loan_financials_cells import LoanFinancialsCells
from fincura.model.loan_financials_data_columns import LoanFinancialsDataColumns
from fincura.model.loan_financials_template_items import LoanFinancialsTemplateItems
from fincura.model.loan_guarantors import LoanGuarantors
from fincura.model.loan_periods import LoanPeriods
from fincura.model.loan_prior_year_financials import LoanPriorYearFinancials
from fincura.model.portfolio import Portfolio
from fincura.model.tenant_settings import TenantSettings
from fincura.model.webhook import Webhook
